@@ -64,16 +64,31 @@ GpsPos::GpsPos(QObject *parent, bool fout, QString posm, bool date, bool time) :
     }
 }
 // call for loop
-GpsPos::GpsPos(QObject *parent, int runs, int limit, bool lastkv, bool showsat, bool fout, QString posm, int interval, bool date, bool time, QString logmethod, bool newtrack, bool script) :
+GpsPos::GpsPos(QObject *parent, int runs, int limit, bool lastkv, bool showsat, bool fout, QString posm, int interval, bool date, bool time, QString logmethod, bool newtrack, bool script, int tout) :
     QObject(parent)
 {
+    #if defined(Q_OS_SAILFISH)
+    g_run=-1;
+#else
     g_run=0;
+#endif
     g_runs=runs;
     full_out=fout;
     limit_acc=limit;
     log_method=logmethod;
     b_date=date;
     b_time=time;
+    timeout_value=tout;
+    //qDebug() << "timeout=" << timeout_value;
+    if (timeout_value > 0)
+    {
+        timeout_value=timeout_value*1000;
+        timer = new QTimer(this);
+        connect(timer, SIGNAL(timeout()), this, SLOT(timeout()));
+        timer->start(timeout_value);
+        //qtimer
+        //connect sgtimout
+    }
 
     if (!script)
     {
@@ -84,30 +99,37 @@ GpsPos::GpsPos(QObject *parent, int runs, int limit, bool lastkv, bool showsat,
     if (newtrack) writelogfile("newtrack");
 
     QGeoPositionInfoSource *source = QGeoPositionInfoSource::createDefaultSource(this);
-    if (interval!=0) source->setUpdateInterval(interval);
+    if (interval!=0) source->setUpdateInterval(interval*1000);
     if (posm=="onlysat") source->setPreferredPositioningMethods(QGeoPositionInfoSource::SatellitePositioningMethods);
     else if (posm=="nonesat") source->setPreferredPositioningMethods(QGeoPositionInfoSource::NonSatellitePositioningMethods);
     else if (posm=="all") source->setPreferredPositioningMethods(QGeoPositionInfoSource::AllPositioningMethods);
     if (source) {
-        connect(source, SIGNAL(positionUpdated(QGeoPositionInfo)),
-                this, SLOT(positionUpdated(QGeoPositionInfo)));
+        //qDebug() << source->supportedPositioningMethods();
+        //connect(source, SIGNAL(positionUpdated(QGeoPositionInfo)), this, SLOT(positionUpdated(QGeoPositionInfo)),static_cast<Qt::ConnectionType>(Qt::DirectConnection | Qt::UniqueConnection));
+        connect(source, SIGNAL(positionUpdated(QGeoPositionInfo)), this, SLOT(positionUpdated(QGeoPositionInfo)));
         if (lastkv)
         {
             qDebug() << "lastknownposition: " << source->lastKnownPosition(false);
         }
-
-        source->startUpdates();
+        /*if (runs==1)
+        {
+            connect(source, SIGNAL(updateTimeout()), this, SLOT(timeout()));
+            source->requestUpdate(15000);
+        }
+        else
+        {*/
+            //connect(source, SIGNAL(updateTimeout()), this, SLOT(timeout()));
+            source->startUpdates();
+        //}
     }
     if (showsat && posm!="nonesat")
     {
         QGeoSatelliteInfoSource *sats = QGeoSatelliteInfoSource::createDefaultSource(this);
-        if (interval!=0) source->setUpdateInterval(interval);
+        if (interval!=0) source->setUpdateInterval(interval*1000);
              // Listen satellite status changes
              if (sats != 0) {
-                 connect(sats, SIGNAL(satellitesInViewUpdated(const QList<QGeoSatelliteInfo>&)),
-                         this, SLOT(satellitesInViewUpdated(const QList<QGeoSatelliteInfo>&)));
-                 connect(sats, SIGNAL(satellitesInUseUpdated(const QList<QGeoSatelliteInfo>&)),
-                         this, SLOT(satellitesInUseUpdated(const QList<QGeoSatelliteInfo>&)));
+                 connect(sats, SIGNAL(satellitesInViewUpdated(const QList<QGeoSatelliteInfo>&)), this, SLOT(satellitesInViewUpdated(const QList<QGeoSatelliteInfo>&)));
+                 connect(sats, SIGNAL(satellitesInUseUpdated(const QList<QGeoSatelliteInfo>&)), this, SLOT(satellitesInUseUpdated(const QList<QGeoSatelliteInfo>&)));
                  sats->startUpdates();
              }
     }
@@ -139,7 +161,23 @@ void GpsPos::positionUpdated(const QGeoPositionInfo &info)
         qreal horizontalacc = info.attribute(QGeoPositionInfo::HorizontalAccuracy);
         qreal verticalacc = info.attribute(QGeoPositionInfo::VerticalAccuracy);
         QTextStream cout(stdout);
+        if (timeout_value>0)
+        {
+            timer->stop();
+            timer->start();
+            //qtimer start stop
+        }
+        #if defined(Q_OS_SAILFISH)
+        if (g_run==-1 && log_method=="onlysat")
+        {
+            g_run++;
+        }
+
+        else {
+            if (g_run==-1) g_run++;
+#endif
         g_run++;
+
         //qDebug()  << g_run << g_runs << limit_acc << verticalacc << horizontalacc;
         if ((limit_acc==0) || ((verticalacc < limit_acc) && (horizontalacc < limit_acc)))
         {
@@ -205,6 +243,9 @@ void GpsPos::positionUpdated(const QGeoPositionInfo &info)
             quit("x");
         }
     }
+#if defined(Q_OS_SAILFISH)
+    }
+#endif
 }
 
 void GpsPos::lastknownposition(const QGeoPositionInfo &lastpos)
@@ -342,11 +383,18 @@ void GpsPos::writegpxdata()
     qDebug() << "..finished";
 }
 
+void GpsPos::timeout()
+{
+    qDebug() << "timeout user input reached";
+    quit("x");
+}
+
 void GpsPos::quit(QString input)
 {
     //qDebug() << "input:" << input << ";test";
     if (input=="x")
     {
+        //source->stopUpdates();
         if (log_method=="gpx") writegpxdata();
         emit finished();
     }
