@@ -42,6 +42,7 @@ int main(int argc, char *argv[])
         if (QArgByKey("runs",'=').toInt()!=0) myMain.g_runs = QArgByKey("runs",'=').toInt();
         else myMain.g_runs=-1;
         myMain.g_limit = QArgByKey("limit",'=').toInt();
+        myMain.g_tout = QArgByKey("tout",'=').toInt();
         myMain.g_sat = qApp->arguments().contains("--sat");
         myMain.g_fout = qApp->arguments().contains("--fout");
         myMain.g_lknv = qApp->arguments().contains("--lknv");
@@ -51,6 +52,7 @@ int main(int argc, char *argv[])
         myMain.g_newtrack = qApp->arguments().contains("--newtrack");
         myMain.g_interval = QArgByKey("intval",'=').toInt();
         myMain.g_del = qApp->arguments().contains("--del");
+        //myMain.g_time = qApp->arguments().contains("--tout");
         if (QArgByKey("log",'=').toLatin1()!="") myMain.g_log = QArgByKey("log",'=').toLatin1();
         else myMain.g_log = "none";
         if (QArgByKey("posm",'=').toLatin1()!="") myMain.g_posm = QArgByKey("posm",'=').toLatin1();
@@ -64,15 +66,16 @@ int main(int argc, char *argv[])
         {
             QTextStream cout(stdout);
             cout << endl;
-            cout << "gpscon v0.0.8 by halftux" << endl << endl;
+            cout << "gpscon v0.0.9 by halftux" << endl << endl;
             cout << "Options:" << endl;
             cout << "--------" << endl;
             cout << "  [--help] help output" << endl;
             cout << "  [runs=integer] max update runs before quit" << endl;
             cout << "  [limit=integer] accuracy vert/hori < limit 1x and quit" << endl;
             cout << "  [posm=string]Position method: nonesat / all / onlysat" << endl;
-            cout << "  [interval=integer] update interval" << endl;
+            cout << "  [interval=integer] update interval in s" << endl;
             cout << "  [log=string] txt/gpx/log2gpx" << endl;
+            cout << "  [tout=integer] timeout to exit in s" << endl;
             cout << "  [--del] deleting log files" << endl;
             cout << "  [--sat] with satellite output" << endl;
             cout << "  [--fout] full position output" << endl;
